#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 constraints-extras
version:              0.3.1.0
visibility:           public
id:                   constraints-extras-0.3.1.0-9ONvoWdVhBjAowLiFsZ3kM
key:                  constraints-extras-0.3.1.0-9ONvoWdVhBjAowLiFsZ3kM
license:              BSD-3-Clause
copyright:            Obsidian Systems LLC
maintainer:           maintainer@obsidian.systems
author:               Cale Gibbard, Ali Abrar
homepage:             https://github.com/obsidiansystems/constraints-extras
synopsis:             Utility package for constraints
description:
    Convenience functions and TH for working with constraints. See <https://github.com/obsidiansystems/constraints-extras/blob/develop/README.md README.md> for example usage.

category:             Constraints
abi:                  67f62d698d3c8439221d6cf5500e0362
exposed:              True
exposed-modules:
    Data.Constraint.Compose Data.Constraint.Extras
    Data.Constraint.Extras.TH Data.Constraint.Flip

import-dirs:          /usr/lib/ghc-8.10.5/site-local/constraints-extras-0.3.1.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/constraints-extras-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/constraints-extras-0.3.1.0
hs-libraries:         HSconstraints-extras-0.3.1.0-9ONvoWdVhBjAowLiFsZ3kM
depends:
    base-4.14.2.0 constraints-0.13-AnR9rNxGX5VB941qwyLpm4
    template-haskell-2.16.0.0

haddock-interfaces:
    /usr/share/doc/haskell-constraints-extras/html/constraints-extras.haddock

haddock-html:         /usr/share/doc/haskell-constraints-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

